@@ -180,9 +180,21 @@ class FontItem( object ):
 					#self.family.append( font.getname()[0] ) # old code
 
 					## No point Try-ing here, this segfaults when style/family is Null.
-					self.family.append( fpsys.LSP.ensure_unicode( font.getname()[0] ) )
 
-					self.style.append( font.getname()[1] )
+					## July 2016
+					## =========
+					## Font caused an error. Here it is:
+					##  chinese_rocks_rg-webfont.ttf [None] ['\x7f']
+					## The None is the problem.
+					n = fpsys.LSP.ensure_unicode( font.getname()[0] )
+					if n is None: n=""
+					self.family.append( n )
+
+					## July 2016: Let's assure no None in the style too
+					n = font.getname()[1]
+					if n is None: n=""
+					self.style.append( n )
+
 					i += 1
 				else:
 					## It WAS in the list! So, we can flag it and get on with life :)
@@ -661,6 +673,16 @@ class Pog(BasicFontList):
 		if self.__installed == "yes": return True
 		if self.__installed == "no": return False		
 		
+	def setInstalledFlag(self, TF):
+		"""
+		JULY 2016
+		=========
+		In a situation where we have two objects of the same Pog, and one is installed
+		we need to set the other one to installed too.
+		See gui_Right multiClick
+		"""
+		self.__installed = TF
+
 	def __renameBadPog(self):
 		"""
 		This is a bad pog, My plan is to rename it out of the .pog namespace.
@@ -751,7 +773,7 @@ class Pog(BasicFontList):
 			PogAllFontsFailedToInstall
 			PogSomeFontsDidNotInstall
 			NoFontsDir
-		"""	
+		"""
 		if not os.path.exists(self.__pc.userFontPath()):
 			raise fontybugs.NoFontsDir("Missing .fonts dir")
 
@@ -804,12 +826,14 @@ class Pog(BasicFontList):
 			self.__installed = "no"
 			self.write()
 			raise fontybugs.PogAllFontsFailedToInstall(self.name) # RAISED :: PogAllFontsFailedToInstall
-		elif bugs > 0: 
+		elif bugs > 0:
 			## Some fonts did get installed, but not all. so, we are INSTALLED
 			self.write()
+			#print "   semi [INSTALL COMPLETE]"
+			#print self.__installed
 			raise fontybugs.PogSomeFontsDidNotInstall(self.name) # RAISED :: PogSomeFontsDidNotInstall
+
 		self.write()
-		#print "    [INSTALL COMPLETE]"
 
 		
 	def uninstall(self):
@@ -915,6 +939,12 @@ class Pog(BasicFontList):
 				bugs=True
 				# e.errno == errno.ENOENT: # No such file or directory
 				print e # whatever is wrong, print the message and continue
-
+			## July 2016
+			## =========
+			## Randomly saw this error: ValueError('ZIP does not support timestamps before 1980')
+			## HAND. Added this new except with a message.
+			except ValueError,e:
+				bugs=True
+				print _("%s failed to zip because %s" % (fi.glyphpaf, e))
 		file.close()		
 		return bugs # a flag for later.
