@@ -123,7 +123,8 @@ class FontViewPanel(wx.Panel):
 
 		## The filter text box
 		self.textFilter = wx.StaticText(self, -1, _("Filter:"))
-		self.inputFilter = wx.ComboBox(self, 500, value="", choices=[],style=wx.CB_DROPDOWN )
+		#July 5th, 2016: Had to add "|wx.TE_PROCESS_ENTER" to get the input filter's EVT_TEXT_ENTER event to work. Go figure.
+		self.inputFilter = wx.ComboBox(self, 500, value="", choices=[],style=wx.CB_DROPDOWN|wx.TE_PROCESS_ENTER )
 		self.Bind(wx.EVT_COMBOBOX, self.EvtComboBox, self.inputFilter)
 		self.Bind(wx.EVT_TEXT_ENTER, self.EvtTextEnter, self.inputFilter)
 
@@ -144,7 +145,7 @@ class FontViewPanel(wx.Panel):
 		idItalic = wx.NewId()
 		self.idRegular = wx.NewId()
 		self.BIR = {
-				idBold:			{'style': "bold", 	'label': _("b"), 'truth': False, 'instance': None},
+				idBold:			{'style': "bold",   'label': _("b"), 'truth': False, 'instance': None},
 				idItalic:		{'style': "italic", 'label': _("i"), 'truth': False, 'instance': None},
 				self.idRegular: {'style': "regular",'label': _("r"), 'truth': False, 'instance': None}
 				}
@@ -163,13 +164,21 @@ class FontViewPanel(wx.Panel):
 		self.scrolledFontView = ScrolledFontView(self) 
 		
 		buttonsSizer = wx.BoxSizer(wx.HORIZONTAL) 
-		self.buttPrev = wx.Button(self, wx.ID_BACKWARD) # Also not in Afrikaans.
+
+		#July 2016
+		#=========
+		#The stock icon on the button was not showing under gtk3.
+		#I have switched to a bitmapbutton. I hope this works...
+		#self.buttPrev = wx.Button(self, wx.ID_BACKWARD) # Also not in Afrikaans.
+		self.buttPrev = wx.BitmapButton( self, wx.ID_BACKWARD, wx.ArtProvider.GetBitmap( wx.ART_GO_BACK, wx.ART_BUTTON, (32,32) ))
 
 		self.buttMain = wx.Button(self, label=" ")
 		self.buttMainLastLabel=" "
+
 		## This stock button has not been translated into Afrikaans yet. (Dec 2007)
 		## I can't tell you how this fkuced me around!
-		self.buttNext = wx.Button(self, wx.ID_FORWARD)  
+		# July 2016 - remarked : self.buttNext = wx.Button(self, wx.ID_FORWARD)  
+		self.buttNext = wx.BitmapButton( self, wx.ID_FORWARD, wx.ArtProvider.GetBitmap( wx.ART_GO_FORWARD, wx.ART_BUTTON, (32,32) ))
 		self.buttPrev.Enable(False)  #Starts out disabled
 		
 		buttonsSizer.Add(self.buttPrev,0,wx.EXPAND) 
@@ -208,7 +217,7 @@ class FontViewPanel(wx.Panel):
 		ps.sub( update_font_view, self.MainFontViewUpdate ) ##DND: class FontViewPanel
 		ps.sub( reset_to_page_one, self.ResetToPageOne ) ##DND: class FontViewPanel 
 	
-	#def DoGetBestSize(self):
+		#def DoGetBestSize(self):
 		# DOES NOT RUN FOR A wx.Panel
 
 	def OnClearClick( self, event ):
@@ -254,11 +263,12 @@ class FontViewPanel(wx.Panel):
 	# hits ENTER.
 	def EvtTextEnter(self, evt):
 		o=evt.GetEventObject()
+		#print dir(o)
 		termsstring = evt.GetString()
 		history=o.GetItems()
 		if termsstring not in history:
 			o.Insert( termsstring,0 ) #record this search in the top of the 'history'
-		
+		#print termsstring
 		self.startSearch(termsstring)
 		
 		self.buttMain.SetFocus()
